aboutsummaryrefslogtreecommitdiffstats
path: root/src/lib/tls/tls_client.h
diff options
context:
space:
mode:
authorJack Lloyd <[email protected]>2018-05-07 13:39:01 -0400
committerJack Lloyd <[email protected]>2018-05-07 13:39:01 -0400
commit312f0194e09a2f2cef5af3750fd750a1d0137945 (patch)
treefd5af810a578619b638b0daf76ebb9de711ceb0b /src/lib/tls/tls_client.h
parent143e1a0ada9ad2b35985d1e32345a94c2080bc25 (diff)
Fix some warnings new in GCC 8.1
It thinks the typedefs are "locals" that are being conflicted with, which seems wrong to me but whatever.
Diffstat (limited to 'src/lib/tls/tls_client.h')
-rw-r--r--src/lib/tls/tls_client.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/src/lib/tls/tls_client.h b/src/lib/tls/tls_client.h
index 67a086e15..63c26b9cd 100644
--- a/src/lib/tls/tls_client.h
+++ b/src/lib/tls/tls_client.h
@@ -63,15 +63,16 @@ class BOTAN_PUBLIC_API(2,0) Client final : public Channel
/**
* DEPRECATED. This constructor is only provided for backward
- * compatibility and should not be used in new code.
- *
+ * compatibility and should not be used in new code. It will be
+ * removed in a future release.
+ *
* Set up a new TLS client session
*
* @param output_fn is called with data for the outbound socket
*
* @param app_data_cb is called when new application data is received
*
* @param alert_cb is called when a TLS alert is received
*
* @param hs_cb is called when a handshake is completed
*
@@ -95,9 +96,9 @@ class BOTAN_PUBLIC_API(2,0) Client final : public Channel
* values just mean reallocations and copies are more likely.
*/
BOTAN_DEPRECATED("Use TLS::Client(TLS::Callbacks ...)")
- Client(output_fn output_fn,
+ Client(output_fn data_output_fn,
data_cb app_data_cb,
- alert_cb alert_cb,
+ alert_cb recv_alert_cb,
handshake_cb hs_cb,
Session_Manager& session_manager,
Credentials_Manager& creds,
@@ -63,15 +63,16 @@ class BOTAN_PUBLIC_API(2,0) Client final : public Channel
* Set up a new TLS client session
*
- * @param output_fn is called with data for the outbound socket
+ * @param data_output_fn is called with data for the outbound socket
*
* @param app_data_cb is called when new application data is received
@@ -63,15 +63,16 @@ class BOTAN_PUBLIC_API(2,0) Client final : public Channel
* @param app_data_cb is called when new application data is received
*
- * @param alert_cb is called when a TLS alert is received
+ * @param recv_alert_cb is called when a TLS alert is received
*
* @param hs_cb is called when a handshake is completed